﻿using System.Windows;
using System.Windows.Controls;
using Microsoft.Practices.Composite.Modularity;
using Microsoft.Practices.Composite.Regions;
using Telerik.Windows.Controls.TransitionEffects;

namespace Prism.Shell
{
	public partial class Shell : UserControl
	{
		private IRegionManager regionManager;
		private IModuleManager moduleManager;

		public Shell(IRegionManager regionManager, IModuleManager moduleManager)
		{
			// Get reference to the region and module manager
			this.regionManager = regionManager;
			this.moduleManager = moduleManager;

			InitializeComponent();

			// You can set every transition you like here.
			this.module1Region.Transition = new MotionBlurredZoomTransition();
			this.module2Region.Transition = new MotionBlurredZoomTransition();
		}

		private bool module1Loaded, module2Loaded;

		private void RadOutlookBar_SelectionChanged(object sender, RoutedEventArgs e)
		{
			if (this.outlookBar1.SelectedIndex == 0)
			{
				// Has the module been loaded already?
				if (!this.module1Loaded)
				{
					// If it is not loaded, load the module and turn off the flag so that we do not load the module again.
					this.moduleManager.LoadModule("Prism.Module1.InitModule");
					this.module1Loaded = true;
				}
				else
				{
					// If the module has already been activated, get a reference to the view
					var module1View = this.regionManager.Regions["Module1Region"].GetView("Module1View");

					// Deactivate the view. 
					// Deactivation is necessary so that the TransitionControl can play its transition animation
					if (module1View != null)
					{
						this.regionManager.Regions["Module1Region"].Deactivate(module1View);
					}

					// Activate the view
					if (module1View != null)
					{
						this.regionManager.Regions["Module1Region"].Activate(module1View);
					}
				}
			}

			if (this.outlookBar1.SelectedIndex == 1)
			{
				// Has the module been loaded already?
				if (!this.module2Loaded)
				{
					// If it is not loaded, load the module and turn off the flag so that we do not load the module again.
					this.moduleManager.LoadModule("Prism.Module2.InitModule");
					this.module2Loaded = true;
				}
				else
				{
					// If the module has already been activated, get a reference to the view
					var module2View = this.regionManager.Regions["Module2Region"].GetView("Module2View");

					// Deactivate the view. 
					// Deactivation is necessary so that the TransitionControl can play its transition animation
					if (module2View != null)
					{
						this.regionManager.Regions["Module2Region"].Deactivate(module2View);
					}

					// Activate the view
					if (module2View != null)
					{
						this.regionManager.Regions["Module2Region"].Activate(module2View);
					}
				}
			}
		}
	}
}
